package handler

import (
	"errors"
	"net/http"

	"github.com/zeromicro/go-zero/core/logx"
	"github.com/zeromicro/go-zero/rest/httpx"

	"fusenapi/server/product/internal/logic"
	"fusenapi/server/product/internal/svc"
	"fusenapi/server/product/internal/types"
)

func GetProductListHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.GetProductListReq
		if err := httpx.Parse(r, &req); err != nil {
			httpx.OkJsonCtx(r.Context(), w, &types.Response{
				Code:    510,
				Message: err.Error(),
			})
			logx.Info(err)
			return
		}

		l := logic.NewGetProductListLogic(r.Context(), svcCtx)
		resp := l.GetProductList(&req)
		if resp != nil {
			httpx.OkJsonCtx(r.Context(), w, resp)
		} else {
			err := errors.New("server logic is error, resp must not be nil")
			httpx.ErrorCtx(r.Context(), w, err)
			logx.Error(err)
		}
	}
}
